@@ -1,11 +1,12 @@
 // SPDX-License-Identifier: LGPL-2.1-or-later
 // Copyright (c) 2012-2014 Monty Program Ab
-// Copyright (c) 2015-2023 MariaDB Corporation Ab
+// Copyright (c) 2015-2024 MariaDB Corporation Ab
 package org.mariadb.jdbc.client.impl;
 
 import java.io.*;
 import java.net.Socket;
 import java.net.SocketException;
+import java.net.SocketTimeoutException;
 import java.sql.ResultSet;
 import java.sql.SQLException;
 import java.sql.SQLNonTransientConnectionException;
@@ -395,6 +396,15 @@ public class StandardClient implements Client, AutoCloseable {
         }
         throw exceptionFactory.create("Initialization command fail", "08000", sqlException);
       }
+
+      if (conf.returnMultiValuesGeneratedIds()) {
+        ClientMessage query = new QueryPacket("SELECT @@auto_increment_increment");
+        List<Completion> res = execute(query, true);
+        ResultSet rs = (ResultSet) res.get(0);
+        if (rs.next()) {
+          context.setAutoIncrement(rs.getLong(1));
+        }
+      }
     }
   }
 
@@ -427,6 +437,15 @@ public class StandardClient implements Client, AutoCloseable {
           "autocommit=" + ((conf.autocommit() == null || conf.autocommit()) ? "1" : "0"));
     }
 
+    if (conf.returnMultiValuesGeneratedIds()
+        && ((context.getVersion().isMariaDBServer()
+                && (context.getVersion().versionGreaterOrEqual(10, 2, 2)))
+            || context.getVersion().versionGreaterOrEqual(5, 7, 0))) {
+      sessionCommands.add(
+          "session_track_system_variables ="
+              + " CONCAT(@@global.session_track_system_variables,',auto_increment_increment')");
+    }
+
     // add configured session variable if configured
     if (conf.sessionVariables() != null) {
       sessionCommands.add(Security.parseSessionVariables(conf.sessionVariables()));
@@ -916,7 +935,12 @@ public class StandardClient implements Client, AutoCloseable {
       destroySocket();
       throw exceptionFactory
           .withSql(message.description())
-          .create("Socket error", "08000", ioException);
+          .create(
+              ioException instanceof SocketTimeoutException
+                  ? "Socket timout error"
+                  : "Socket error",
+              "08000",
+              ioException);
     }
   }
 
